@@ -15,7 +15,7 @@ all the user actions to CEM fo logging/mentor input/game input."
 
 #include "gui.h"
 #include "chum.h"
-#include "file_helper.h"
+
 
 #include "../cem/cem.h"
 #include "../meam/jammo-meam.h"
@@ -24,10 +24,11 @@ all the user actions to CEM fo logging/mentor input/game input."
 #include "../meam/jammo-recording-track.h"
 #include "../meam/jammo-instrument-track.h"
 #include "../meam/jammo-slider-track.h"
+#include "../meam/jammo-playing-track.h"
 
 #include "../gems/gems.h"
 
-#include "../gui_clutter/instrument_testing.h"
+
 static int chum_count_themes();
 
 
@@ -77,13 +78,17 @@ char *name_of_states[] ={ "SCREEN_WELCOME",
                           "SCREEN_SONG_SELECTION",
                           "SCREEN_SONG_RECORDING",
                           "SCREEN_PLAY_RECORDED",
-                          "SCREEN_PLAY_RECORDED",
-                          "SCREEN_MIDI_EDITOR" };
+                          "SCREEN_MIDI_EDITOR",
+                          "SCREEN_SEQUENCER",
+                          "SCREEN_STARTMENU",
+                          "SCREEN_GAMESMENU",
+                          "SCREEN_COMMUNITYMENU"};
 
 static JammoSequencer* sequencer = NULL;
 JammoEditingTrack* editing_track;
 JammoEditingTrack* editing_track_partner; //pairgame for youngest group
 JammoEditingTrack* backing_track;
+JammoPlayingTrack* playing_track;
 
 JammoInstrumentTrack* instrument_track;
 JammoSliderTrack* slider_track;
@@ -175,6 +180,15 @@ void chum_start_chum(int argc, char** argv){
     else if (argc==2 && strcmp(argv[1],"sequencer")==0) {
         state_of_chum=SCREEN_SEQUENCER;
         }
+    else if (argc==2 && strcmp(argv[1],"startmenu")==0) {
+           state_of_chum=SCREEN_STARTMENU;
+           }
+    else if (argc==2 && strcmp(argv[1],"gamesmenu")==0) {
+               state_of_chum=SCREEN_GAMESMENU;
+               }
+    else if (argc==2 && strcmp(argv[1],"communitymenu")==0) {
+                   state_of_chum=SCREEN_COMMUNITYMENU;
+                   }
 
     else if (argc==3 && strcmp(argv[1],"instrument")==0) { 
         start_test_instrument(atoi(argv[2]));
@@ -198,6 +212,7 @@ void chum_test_instrument(int type) {
 	cem_add_to_log(g_strdup_printf("chum_test_instrument(%d)",type),LOG_DEBUG);
 	sequencer = jammo_sequencer_new();
 	instrument_track = jammo_instrument_track_new(type);
+	jammo_instrument_track_set_realtime(instrument_track,TRUE);
 	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(instrument_track));
 	
   //Instrument track doesn't work if there aren't another track with one sample.
@@ -374,11 +389,11 @@ Always call this before gui_go_screen(SCREEN_PLAY_RECORDED);
 */
 void chum_play_recorded_and_backing_track(){
     chum_stop_sequencer();
-    /*
+
 	if (sequencer) {
 		g_object_unref(sequencer);
 	}
-    */
+
 	sequencer = jammo_sequencer_new();
 
 	backing_track = chum_create_new_empty_track(); //for comping track
@@ -392,18 +407,21 @@ void chum_play_recorded_and_backing_track(){
      filename = g_strdup_printf("%s/songs/%s/comping.ogg", DATA_DIR,chum_get_current_song()); //use without language postfix
      }
 
-    chum_add_new_sample_to_track_nth_slot(backing_track, NULL,filename,0);
+    JammoSample* sample1 = jammo_sample_new_from_file(filename);
+    jammo_editing_track_add_sample(backing_track, sample1, 0);
     g_free(filename);
 
+    gchar* recording_filename = g_strdup_printf("%s/last_recorded.wav",JAMMO_DIRECTORY);
     editing_track = chum_create_new_empty_track(); //for recorded singing
-    chum_add_new_sample_to_track_nth_slot(editing_track,NULL,RECORDING_FILENAME,0);
+    JammoSample* sample2 = jammo_sample_new_from_file(recording_filename);
+    g_free(recording_filename);
+    jammo_editing_track_add_sample(editing_track, sample2, 0);
+
     state_of_chum=SCREEN_PLAY_RECORDED;
 }
 
 
 void chum_change_to_song(const char *song_name){
-  JammoSample* sample1;
-
     cem_add_to_log(g_strdup_printf("chum_change_to_song(%s)",song_name),LOG_DEBUG);
     current_song=song_name;
 
@@ -437,19 +455,18 @@ void chum_change_to_song(const char *song_name){
     }
 
   printf("looking for file '%s' \n",filename);
-  backing_track = jammo_editing_track_new();   //for comping track
-  jammo_sequencer_add_track(sequencer, JAMMO_TRACK(backing_track));
-
-  sample1 = jammo_sample_new_from_file(filename);
-  jammo_editing_track_add_sample(backing_track, sample1, 0);
+  playing_track = jammo_playing_track_new(filename);   //for comping track
+  jammo_sequencer_add_track(sequencer, JAMMO_TRACK(playing_track));
 
+  gchar* recording_filename = g_strdup_printf("%s/last_recorded.wav",JAMMO_DIRECTORY);
   //Do not use pitch_detect on OFFICIAL_RELEASE (not robust enough)
   #ifdef OFFICIAL_RELEASE
-  recording_track = jammo_recording_track_new(RECORDING_FILENAME);
+  recording_track = jammo_recording_track_new(recording_filename);
   #else
-  recording_track = jammo_recording_track_new_with_pitch_detect(RECORDING_FILENAME);
+  recording_track = jammo_recording_track_new_with_pitch_detect(recording_filename);
   #endif
-
+  g_free(recording_filename);
+ 
   jammo_sequencer_add_track(sequencer, JAMMO_TRACK(recording_track));
 
   state_of_chum=SCREEN_SONG_RECORDING;
