@@ -15,25 +15,24 @@ This file is for clutter based gui and it handles config file reading
 /**
  * Defines default folders.
  */
-/*
-#define THEMES_DIR "../share/jammo/themes"
-#define SONGS_DIR "../share/jammo/songs"
-*/
-//In n900 we should use /opt for data files. And maybe this is not bad place for all systems?
 
 #define DATA_DIR "/opt/jammo"
 #define SEQUENCER_DIR "/opt/jammo/sequencer"
-
+#define STARTMENU_DIR "/opt/jammo/startmenu"
+#define GAMESMENU_DIR "/opt/jammo/gamesmenu"
+#define COMMUNITYMENU_DIR "/opt/jammo/communitymenu"
 #define THEMES_DIR DATA_DIR "/themes"
 #define SONGS_DIR DATA_DIR "/songs"
 
 //N900 has very limited /tmp space.
 #ifdef N900
-#define RECORDING_FILENAME "/home/user/.jammo/recording.wav"
+#define JAMMO_DIRECTORY "/home/user/MyDocs/jammo"
 #else
-#define RECORDING_FILENAME "/tmp/recording.wav"
+#define JAMMO_DIRECTORY "/tmp/jammo"
 #endif
 
+#define COMPOSITIONS_DIRECTORY JAMMO_DIRECTORY "/compositions"
+#define SINGINGS_DIRECTORY JAMMO_DIRECTORY "/singings"
 
 /* This is temporary location: move to jammo.h or similar. */
 ClutterActor* jammo_get_actor_by_id(const gchar* id);
