@@ -37,11 +37,7 @@ void cupboard_song_icon_clicked(ClutterTexture *actor2, ClutterEvent *event, gpo
 	printf("Load song_icon pressed: '%s'\n",(char*)data);
 
 	gchar *filename;
-		#ifdef N900
-	filename = g_strdup_printf("/home/user/MyDocs/jammo/singings/%s.wav",(char*)data);
-	#else
-	filename = g_strdup_printf("/tmp/jammo/singings/%s.wav",(char*)data);
-	#endif
+	filename = g_strdup_printf("%s/%s.wav",SINGINGS_DIRECTORY,(char*)data);
 
 	JammoSample*	sample = jammo_sample_new_from_file(filename);
 	g_free(filename);
@@ -66,12 +62,8 @@ void cupboard_door_clicked(TangleAction *action, GObject *source, const gchar *t
 
 	//Load compositions TODO. This is just test-version with one icon.
 	gchar *filepath1;
-	#ifdef N900
-	filepath1 = g_strdup_printf("/home/user/MyDocs/jammo/compositions");;
-	#else
-	filepath1 = g_strdup_printf("/tmp/jammo/compositions");
-	#endif
-
+	filepath1 = COMPOSITIONS_DIRECTORY;
+	
 	GList* files = file_helper_get_all_files(filepath1);
 
 	GList* l;
@@ -90,11 +82,7 @@ void cupboard_door_clicked(TangleAction *action, GObject *source, const gchar *t
 
 	
 	//And singings
-	#ifdef N900
-	filepath1 = g_strdup_printf("/home/user/MyDocs/jammo/singings");
-	#else
-	filepath1 = g_strdup_printf("/tmp/jammo/singings");
-	#endif
+	filepath1 = SINGINGS_DIRECTORY;
 
 	files = file_helper_get_all_files(filepath1);
 
