@@ -21,6 +21,9 @@ enum {
   SCREEN_PLAY_RECORDED,
   SCREEN_MIDI_EDITOR,
   SCREEN_SEQUENCER,
+  SCREEN_STARTMENU,
+  SCREEN_GAMESMENU,
+  SCREEN_COMMUNITYMENU,
   NUMBER_OF_SCREENS, //Keep this entry last.
 };
 
