@@ -9,6 +9,7 @@
  */
 
 #include "jammo-sample-button.h"
+#include "jammo-track-view.h"
 #include <string.h>
 
 G_DEFINE_TYPE(JammoSampleButton, jammo_sample_button, TANGLE_TYPE_DRAGGABLE_ACTOR);
@@ -78,7 +79,8 @@ void jammo_sample_button_set_sample_filename(JammoSampleButton* sample_button, c
 			g_object_unref(sample_button->priv->sample);
 		}
 		sample_button->priv->sample = jammo_sample_new_from_file(sample_filename);
-		
+		g_object_ref(sample_button->priv->sample);
+
 		g_object_notify(G_OBJECT(sample_button), "sample-filename");
 		g_object_notify(G_OBJECT(sample_button), "sample");
 	}
@@ -98,6 +100,25 @@ void jammo_sample_button_set_sample(JammoSampleButton* sample_button, JammoSampl
 	}
 }
 
+static gboolean jammo_sample_button_end_dragging(TangleDraggableActor* draggable_actor, TangleDragging* dragging) {
+	gboolean retvalue = FALSE;
+	JammoSampleButton* sample_button;
+	ClutterActor* parent;
+	ClutterActor* grand_parent;
+	
+	sample_button = JAMMO_SAMPLE_BUTTON(draggable_actor);
+	
+	parent = clutter_actor_get_parent(CLUTTER_ACTOR(sample_button));
+	grand_parent = clutter_actor_get_parent(parent);
+	if (JAMMO_IS_TRACK_VIEW(grand_parent)) {
+		clutter_container_remove_actor(CLUTTER_CONTAINER(parent), CLUTTER_ACTOR(sample_button));
+	} else {
+		retvalue = TANGLE_DRAGGABLE_ACTOR_CLASS(jammo_sample_button_parent_class)->end_dragging(draggable_actor, dragging);
+	}
+	
+	return retvalue;
+}
+
 static GObject* jammo_sample_button_constructor(GType type, guint n_construct_properties, GObjectConstructParam* construct_properties) {
 	GObject* object;
 	ClutterActor* button;
@@ -162,8 +183,9 @@ static void jammo_sample_button_dispose(GObject* object) {
 	G_OBJECT_CLASS(jammo_sample_button_parent_class)->dispose(object);
 }
 
-static void jammo_sample_button_class_init(JammoSampleButtonClass* klass) {
-	GObjectClass* gobject_class = G_OBJECT_CLASS(klass);
+static void jammo_sample_button_class_init(JammoSampleButtonClass* sample_button_class) {
+	GObjectClass* gobject_class = G_OBJECT_CLASS(sample_button_class);
+	TangleDraggableActorClass* draggable_actor_class = TANGLE_DRAGGABLE_ACTOR_CLASS(sample_button_class);
 
 	gobject_class->constructor = jammo_sample_button_constructor;
 	gobject_class->finalize = jammo_sample_button_finalize;
@@ -171,6 +193,8 @@ static void jammo_sample_button_class_init(JammoSampleButtonClass* klass) {
 	gobject_class->set_property = jammo_sample_button_set_property;
 	gobject_class->get_property = jammo_sample_button_get_property;
 
+	draggable_actor_class->end_dragging = jammo_sample_button_end_dragging;
+
 	/**
 	 * JammoSampleButton:image-filename:
 	 */
