@@ -20,9 +20,21 @@
 #include "chum.h" //e.g set_easy_game
 #include <fcntl.h> //we check some files
 
-#include <pthread.h> 
 #include <string.h>
 
+
+#include "../gui_clutter/midi_editor.h"
+
+#include "../gui_clutter/sequencer.h"
+#include "../gui_clutter/startmenu.h"
+#include "../gui_clutter/communitymenu.h"
+#include "../gui_clutter/gamesmenu.h"
+
+#ifdef N900
+#include <libosso.h>
+#endif
+
+
 static const char* search_path = "/opt/jammo";
 
 /*
@@ -48,40 +60,6 @@ ClutterActor* jammo_get_actor_by_id(const char* id) {
 	return actor;
 }
 
-
-
-
-
-//Disable automatic screen dimming
-#ifdef N900
-#include <libosso.h>
-
-void maemo_heartbeat()
-{
-	osso_context_t *ossocontext = NULL;
-	
-	ossocontext = osso_initialize("jammo", "git", 0, NULL);
-	if (ossocontext==NULL)
-		{
-		printf("error initialization of ossocontext\n");
-		}
-		
-	osso_display_state_on(ossocontext);     //if dimmed, this will light it again
-	osso_display_blanking_pause(ossocontext);
-
-	osso_return_t ret;
-	while(TRUE)
-		{
-		g_usleep( 55 * G_USEC_PER_SEC );
-		ret = osso_display_blanking_pause(ossocontext);
-		if (ret==OSSO_OK) printf ("OSSO_OK\n");
-		else if (ret==OSSO_ERROR) printf ("OSSO_ERROR\n");
-		else if (ret==OSSO_INVALID) printf ("OSSO_INVALID\n");
-		else printf("Unknow return\n");
-		}
-}
-#endif
-
 /* A TangleStylesheet directory is tried to load from the following locations:
  * 	/opt/jammo/stylesheet
  * 	<current_working_directory>/data/stylesheet
@@ -127,26 +105,40 @@ static void add_search_paths(ClutterScript* script) {
 	g_free(development_search_path);
 }
 
-int main(int argc, char** argv) {
+#ifdef N900
+static gboolean pause_display_blanking(gpointer user_data) {
+	osso_context_t* osso_context;
 	
-	#ifdef N900
-	gchar *cmd = g_strdup_printf("mkdir -p /home/user/MyDocs/jammo/compositions");
-	#else
-	gchar *cmd = g_strdup_printf("mkdir -p /tmp/jammo/compositions");
-	#endif
-	int error_code = system(cmd);
-	if (error_code)
-			printf("Error, can't call '%s'\n",cmd);
+	osso_context = (osso_context_t*)user_data;
+	
+	g_return_val_if_fail(osso_display_blanking_pause(osso_context) == OSSO_OK, FALSE);
+	
+	return TRUE;
+}
+#endif
 
-	#ifdef N900
-	cmd = g_strdup_printf("mkdir -p /home/user/MyDocs/jammo/singings");
-	#else
-	cmd = g_strdup_printf("mkdir -p /tmp/jammo/singings");
-	#endif
-	error_code = system(cmd);
-	if (error_code)
-			printf("Error, can't call '%s'\n",cmd);
+/* Be sure there are needed place to save compositions and singings.
+ */
+static void create_directories(void) {
+	gchar* cmd; 
+	
+	cmd= g_strdup_printf("mkdir -p %s",COMPOSITIONS_DIRECTORY);
+	if (system(cmd)) {
+		printf("Error, can't call '%s'\n", cmd);
+	}
 	g_free(cmd);
+	
+	cmd = g_strdup_printf("mkdir -p %s",SINGINGS_DIRECTORY);
+	if (system(cmd)) {
+		printf("Error, can't call '%s'\n", cmd);
+	}
+	g_free(cmd);
+}
+
+int main(int argc, char** argv) {
+#ifdef N900
+	osso_context_t* osso_context;
+#endif
 
 	TangleStylesheet* stylesheet;
 	gchar* filename;
@@ -154,11 +146,24 @@ int main(int argc, char** argv) {
 	GError* error = NULL;
 	GObject* object;
 	ClutterActor* actor;
+	ClutterColor black = { 0, 0, 0, 255 };
 	
 	jammo_meam_init(&argc, &argv);
 	jammo_chum_init(&argc, &argv);
 	srand (time (NULL)); //We will use rand()
 
+#ifdef N900
+	osso_context = osso_initialize("jammo", "git", 0, NULL);
+	g_assert(osso_context != NULL);
+	
+	osso_display_state_on(osso_context);
+	osso_display_blanking_pause(osso_context);
+	
+	g_timeout_add(55000, pause_display_blanking, osso_context);
+#endif
+
+	create_directories();
+
 	/* TODO: Temporary: make sure Mentor classes exists. */
 	printf("%p %p\n", JAMMO_TYPE_MENTOR, JAMMO_TYPE_MENTOR_ACTION);
 
@@ -194,12 +199,12 @@ int main(int argc, char** argv) {
 	actor = CLUTTER_ACTOR(object);
 	
 	stage = clutter_stage_get_default();
+	clutter_stage_set_title(CLUTTER_STAGE(stage), "JamMo");
+	clutter_stage_set_color(CLUTTER_STAGE(stage), &black);
+	clutter_stage_set_key_focus(CLUTTER_STAGE(stage), NULL);
 
 #ifdef N900
 	clutter_stage_set_fullscreen(CLUTTER_STAGE(stage), TRUE);
-	
-	pthread_t preloader_thread;
-	pthread_create(&preloader_thread, NULL, maemo_heartbeat, NULL);
 #else
 	clutter_actor_set_size(stage, 800, 480);
 #endif
@@ -208,6 +213,22 @@ int main(int argc, char** argv) {
 	
 	clutter_actor_show(stage);
 	
+ if (argc==2 && strcmp(argv[1],"editor")==0) { 
+	start_midi_editor();
+	}
+	else if (argc==2 && strcmp(argv[1],"sequencer")==0) {
+		start_sequencer();
+	}
+	else if (argc==2 && strcmp(argv[1],"startmenu")==0) {
+		start_startmenu();
+	}
+	else if (argc==2 && strcmp(argv[1],"gamesmenu")==0) {
+		start_gamesmenu();
+	}
+	else if (argc==2 && strcmp(argv[1],"communitymenu")==0) {
+		start_communitymenu();
+	}
+	
 	clutter_main();
 
 	return 0;
