@@ -128,21 +128,20 @@ void singinggame_song_click(TangleAction *action, GObject *source, const gchar *
 	printf("Song clicked. get_name: '%s'\n",name);
 
 	chum_change_to_song(name);
-	gchar* selected_language=chum_get_selected_language();
-
 
 	gchar* name_of_view;
 	name_of_view = g_strdup_printf("song-%s-view", name );
 	ClutterActor* view = jammo_get_actor_by_id(name_of_view);
 	g_free(name_of_view);
-	
-	
-	gchar *filepath1;
+
+
 	//g_signal_connect(view, "transition-completed", G_CALLBACK(song_view_showed), NULL); FIXME: this needs modifications to json
 	song_view_showed(NULL,NULL,NULL,NULL);
 
 	//Do not use pitch_detect on OFFICIAL_RELEASE (not robust enough)
 	#ifndef OFFICIAL_RELEASE
+	gchar* selected_language=chum_get_selected_language();
+	gchar *filepath1;
 	//contour_cursor = moving thing
 	contour_cursor = clutter_texture_new();
 	filepath1 = g_strdup_printf("%s/songs/%s/cursor%s.png", DATA_DIR, name, selected_language );
@@ -193,9 +192,10 @@ void singinggame_song_click(TangleAction *action, GObject *source, const gchar *
 	g_signal_connect(recording_track, "pitch-detected", G_CALLBACK(on_pitch_detected), NULL);
 	
 	//End of melodic contour
+	g_free(filepath1);
 	#endif /*OFFICIAL_RELEASE */
 	
-	g_free(filepath1);
+
 }
 
 void singinggame_cross_click(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
@@ -241,35 +241,29 @@ void singinggame_cross_click(TangleAction *action, GObject *source, const gchar
 		//And show mentor again
 		tangle_actor_show(TANGLE_ACTOR(jammo_mentor_get_default()));
 
+
+
 		//Automatic saving. THIS MUST BE DOCUMENTED.
-		//filenames look like this: jammo_2010.02.22_21.16.27.wav
+
 		//Saving to cupboard and to log.
 		gchar* cmd;
-		#ifdef N900
-		cmd = g_strdup_printf("cp %s /home/user/MyDocs/jammo/singing_`date +%%Y.%%m.%%d_%%H.%%M.%%S`.wav", RECORDING_FILENAME );
-		#else
-		cmd = g_strdup_printf("cp %s /tmp/jammo/singing_`date +%%Y.%%m.%%d_%%H.%%M.%%S`.wav", RECORDING_FILENAME );
-		#endif
-		
-		int error_code = system(cmd);
-		if (error_code)
+
+
+		//Copy that recorded song to 'singings' and name it.
+		cmd = g_strdup_printf("cp %s/last_recorded.wav %s/%s.wav", JAMMO_DIRECTORY, SINGINGS_DIRECTORY,chum_get_current_song() );
+		if (system(cmd)) 
 			printf("Error, can't call '%s'\n",cmd);
-		
-		#ifdef N900
-		cmd = g_strdup_printf("cp %s /home/user/MyDocs/jammo/singings/%s.wav", RECORDING_FILENAME,chum_get_current_song() );
-		#else
-		cmd = g_strdup_printf("cp %s /tmp/jammo/singings/%s.wav", RECORDING_FILENAME,chum_get_current_song() );
-		#endif
-		
-		error_code = system(cmd);
-		if (error_code)
+
+
+		//And make it permanent copy for carer/researcher. Filenames look like this: log_singing_2010.02.22_21.16.27.wav
+		cmd = g_strdup_printf("cp %s/last_recorded.wav %s/log_singing_`date +%%Y.%%m.%%d_%%H.%%M.%%S`.wav",JAMMO_DIRECTORY,JAMMO_DIRECTORY);
+		if (system(cmd)) 
 			printf("Error, can't call '%s'\n",cmd);
-		
+
 		g_free(cmd);
 		}
-		
-	else printf("Singinggame_cross_click: Error\n");
 
+	else printf("Singinggame_cross_click: Error\n");
 }
 
 
