@@ -21,12 +21,8 @@ static gboolean save_composition() {
 	FILE *ofp;
 	gchar *outputFilename;
 
-	//filenames look like this: jammo_comp_2010.02.22_21.16.27.wav TODO
-	#ifdef N900
-	outputFilename = g_strdup_printf("/home/user/MyDocs/jammo/compositions/jammo_comp");
-	#else
-	outputFilename = g_strdup_printf("/tmp/jammo/compositions/jammo_comp");
-	#endif
+	// TODO: use date and timestamp for filenames
+	outputFilename = g_strdup_printf("%s/composition.txt", COMPOSITIONS_DIRECTORY);
 
 	ofp = fopen(outputFilename, "w");
 	g_free(outputFilename);
@@ -304,9 +300,52 @@ gboolean themeselection_load(gchar* inputFilename) {
 	return FALSE;
 }
 
+/*
+Make colored rectangles and add them to given parent.
+Returns number of used slots (length of color_coding).
+*/
+static int create_backing_track_color_coding(gchar* color_coding, gfloat slot_size, gfloat y_offset,TangleWidget* parent) {
+	ClutterActor* actor;
+	ClutterColor* black  = clutter_color_new(0,0,0,         255);
+	ClutterColor* white  = clutter_color_new(255,255,255,   255);
+	ClutterColor* yellow = clutter_color_new(255, 255, 0,   255);
+	ClutterColor* green  = clutter_color_new(0, 255, 0,     255);
+	ClutterColor* orange = clutter_color_new(255, 165, 0,   255);
+	ClutterColor* blue   = clutter_color_new(25, 25, 112,   255);
+	ClutterColor* red    = clutter_color_new(255, 0, 0,     255);
+	ClutterColor* lblue  = clutter_color_new(100, 149, 237, 255);
+	ClutterColor* violet = clutter_color_new(148,0,211,     255);
+	ClutterColor* pink   = clutter_color_new(255,105,180,   255);
 
+	int max=strlen(color_coding);
+	int i;
+	for (i=0;i<max;i++) 
+		{
+		actor = tangle_widget_new();
+		ClutterColor* color;
+		switch (color_coding[i])
+			{
+			case '#': color =  black         ;break;
+			case 'w': color =  white         ;break;
+			case 'y': color =  yellow        ;break;
+			case 'g': color =  green         ;break;
+			case 'o': color =  orange        ;break;
+			case 'b': color =  blue          ;break;
+			case 'r': color =  red           ;break;
+			case 'l': color =  lblue         ;break;
+			case 'v': color =  violet        ;break;
+			case 'p': color =  pink          ;break;
+			default: color = white;
+			}
 
+		tangle_widget_set_background_color(TANGLE_WIDGET(actor), color);	
+		g_object_set(actor, "width", slot_size, "height", 40.0, "x", i* slot_size, "y", 80.0+y_offset, NULL);
+		clutter_container_add_actor(CLUTTER_CONTAINER(parent), actor);
+		}
+	return max;
+}
 
+#define WIDTH_OF_SLOT 40.0
 void themeselection_start_theme(const gchar* name){
 	printf("Theme '%s' starting.\n",name);
 
@@ -341,7 +380,7 @@ void themeselection_start_theme(const gchar* name){
 	//This is a previous view (themeselection-view). Hide it.
 	ClutterActor* old_view;
 	if ((old_view = jammo_get_actor_by_id("themeselection-view"))) {	
-		tangle_actor_hide_animated(old_view);
+		tangle_actor_hide_animated(TANGLE_ACTOR(old_view));
 	}
 
 
@@ -357,10 +396,16 @@ void themeselection_start_theme(const gchar* name){
 	g_signal_connect (back_to_theme_selection, "button-press-event", G_CALLBACK (back_to_theme_selection_clicked),view);
 
 
+	int tempo_table[] = {0,140,110,90};
+	gchar* background_color_code = "some_default";
+	gchar* backing_track_filepath = "no_any_backing_track";
+	
 	//Advanced game sets this to TRUE
 	gboolean use_two_tracks=FALSE;
 
 	if (chum_is_easy_game()) {
+	backing_track_filepath = g_strdup_printf("%s/%s/%d/backing_track.wav", THEMES_DIR, name, tempo_table[variation]);
+		
 	//Add samplebuttons. There are three themes, and each has three variations.
 	if (strncmp(name,"fantasy",7)==0 && variation==1){
 	create_samplebutton("fantasy","140","donkey.png",  "castle_140_drums_2.wav",        296.0, 103.0,TANGLE_WIDGET(view));
@@ -369,6 +414,8 @@ void themeselection_start_theme(const gchar* name){
 	create_samplebutton("fantasy","140","potion.png",  "castle_140_glockenspiel_1.wav", 129.0, 252.0,TANGLE_WIDGET(view));
 	create_samplebutton("fantasy","140","snake.png",   "castle_140_synth_glide_4.wav",  332.0, 197.0,TANGLE_WIDGET(view));
 	create_samplebutton("fantasy","140","witch.png",   "castle_140_melody_2.wav",       545.0,  31.0,TANGLE_WIDGET(view));
+	
+	background_color_code = "#yyyyyyyyppppppppyyyyyyyypppppppp###";
 	}
 	else if (strncmp(name,"fantasy",7)==0 && variation==2){
 	create_samplebutton("fantasy","110","dragon.png","castle_110_clarinet_4.wav",      221.0,  39.0,TANGLE_WIDGET(view));
@@ -377,6 +424,8 @@ void themeselection_start_theme(const gchar* name){
 	create_samplebutton("fantasy","110","ghost.png", "castle_110_flute_2.wav",         548.0,  26.0,TANGLE_WIDGET(view));
 	create_samplebutton("fantasy","110","owl.png",   "castle_110_owl_2.wav",           627.0, 158.0,TANGLE_WIDGET(view));
 	create_samplebutton("fantasy","110","wolf.png",  "castle_110_wolf_4.wav",           21.0, 204.0,TANGLE_WIDGET(view));
+	
+	background_color_code = "bbbbbbbbbbbbbbbbrrrrrrrrvvvvvvvvbbbb##";
 	}
   else if (strncmp(name,"fantasy",7)==0 && variation==3){
 	create_samplebutton("fantasy","90", "bird.png",    "castle_90_whistle_4.wav",    611.0,  76.0,TANGLE_WIDGET(view));
@@ -385,6 +434,8 @@ void themeselection_start_theme(const gchar* name){
 	create_samplebutton("fantasy","90", "mermaid.png", "castle_90_chimes_4.wav",     434.0, 274.0,TANGLE_WIDGET(view));
 	create_samplebutton("fantasy","90", "prince.png",  "castle_90_brass_2.wav",      628.0, 178.0,TANGLE_WIDGET(view));
 	create_samplebutton("fantasy","90", "unicorn.png", "castle_90_oboe_2.wav",       458.0, 101.0,TANGLE_WIDGET(view));
+	
+	background_color_code = "llllvvvvvvvvllllllllvvvvvvvvrrrrrrrrvvvv";
 	}
 
   else if (strncmp(name,"city",4)==0 && variation==1){
@@ -394,6 +445,8 @@ void themeselection_start_theme(const gchar* name){
 	create_samplebutton("city","140","guitarhero.png", "city_140_guitar_riff_2.wav", 377.0, 102.0,TANGLE_WIDGET(view));
 	create_samplebutton("city","140","kids.png",       "city_140_yell_claps_2.wav",  689.0, 185.0,TANGLE_WIDGET(view));
 	create_samplebutton("city","140","motorcycle.png", "city_140_guitar2_2.wav",     306.0, 205.0,TANGLE_WIDGET(view));
+	
+	background_color_code = "yyyyyyyywwyyyyyyyywwgggggggwyyyyyyyy##";
 	}
   else if (strncmp(name,"city",4)==0 && variation==2){
 	create_samplebutton("city","110",  "beatbox.png", "city_110_beatbox_1.wav",       594.0, 169.0,TANGLE_WIDGET(view));
@@ -402,6 +455,8 @@ void themeselection_start_theme(const gchar* name){
 	create_samplebutton("city","110",  "sign.png",    "city_110_trumpet_2.wav",       479.0, 144.0,TANGLE_WIDGET(view));
 	create_samplebutton("city","110",  "skate.png",   "city_110_gliss_bass_2.wav",    161.0, 121.0,TANGLE_WIDGET(view));
 	create_samplebutton("city","110",  "zeppelin.png","city_110_bass_strings_2.wav",  299.0,   0.0,TANGLE_WIDGET(view));
+	
+	background_color_code = "bbbbbbbbrrrrbbbbrrrrbbbb##";
 	}
 	else if (strncmp(name,"city",4)==0 && variation==3){
 	create_samplebutton("city","90",  "car.png",         "city_90_bass_shaker_2.wav",  286.0, 183.0,TANGLE_WIDGET(view));
@@ -410,6 +465,8 @@ void themeselection_start_theme(const gchar* name){
 	create_samplebutton("city","90",  "icecreamvan.png", "city_90_bell_melody_2.wav",  114.0, 155.0,TANGLE_WIDGET(view));
 	create_samplebutton("city","90",  "jumpingrope.png", "city_90_melody2_2.wav",      651.0, 193.0,TANGLE_WIDGET(view));
 	create_samplebutton("city","90",  "ufo.png",         "city_90_fx_2.wav",           264.0,  11.0,TANGLE_WIDGET(view));
+	
+	background_color_code = "ggggggggyyyyllllgggggggg##";
 	}
 
 	else if (strncmp(name,"animal",6)==0 && variation==1){
@@ -419,6 +476,8 @@ void themeselection_start_theme(const gchar* name){
 	create_samplebutton("animal","140",  "mouse.png",    "animalw_140_ud_2.wav",        310.0, 269.0,TANGLE_WIDGET(view));
 	create_samplebutton("animal","140",  "raven.png",    "animalw_140_vocal2_2.wav",    530.0,  71.0,TANGLE_WIDGET(view));
 	create_samplebutton("animal","140",  "snake.png",    "animalw_140_rainstick_1.wav", 600.0, 249.0,TANGLE_WIDGET(view));
+	
+	background_color_code = "yyyyyyyyoooooooorrrrrrrryyyyyyyy";
 	}
 	else if (strncmp(name,"animal",6)==0 && variation==2){
 	create_samplebutton("animal","110",  "crocodile.png",   "animalw_110_percussion2_2.wav", 226.0, 151.0,TANGLE_WIDGET(view));
@@ -427,6 +486,8 @@ void themeselection_start_theme(const gchar* name){
 	create_samplebutton("animal","110",  "salamander.png",  "animalw_110_percussion1_2.wav", 133.0, 251.0,TANGLE_WIDGET(view));
 	create_samplebutton("animal","110",  "snake.png",       "animalw_110_vibraslap_2.wav",   345.0, 256.0,TANGLE_WIDGET(view));
 	create_samplebutton("animal","110",  "spider.png",      "animalw_110_pluck_2.wav",       617.0, 222.0,TANGLE_WIDGET(view));
+	
+	background_color_code = "ggggggggbbbbbbbbgggggggg#";
 	}
 	else if (strncmp(name,"animal",6)==0 && variation==3){
 	create_samplebutton("animal","90",  "bluebird.png",  "animalw_90_accordion2_2.wav",      533.0,  68.0,TANGLE_WIDGET(view));
@@ -435,6 +496,8 @@ void themeselection_start_theme(const gchar* name){
 	create_samplebutton("animal","90",  "goril.png"  ,   "animalw_90_percussion_bass_2.wav", 329.0, 173.0,TANGLE_WIDGET(view));
 	create_samplebutton("animal","90",  "greenbird.png", "animalw_90_accordion1_2.wav",       74.0, 150.0,TANGLE_WIDGET(view));
 	create_samplebutton("animal","90",  "monkey.png"    ,"animalw_90_percussion_2.wav",      328.0,  30.0,TANGLE_WIDGET(view));
+	
+	background_color_code = "yyyyyyyyggggggggoooooooo##";
 	}
 
 	} //easy game
@@ -507,31 +570,38 @@ else { //advanced
 } //advanced game
 
 
-
+int y_offset =0;
+if (use_two_tracks) y_offset=80;
 	chum_make_sequencer(); //this will make sequencer inside chum
 
-	//Container for tracks (one or two)
+	//Container for tracks (one or two) and backing_track
 	ClutterActor *container_for_tracks = tangle_widget_new();
-	clutter_actor_set_size(container_for_tracks, 2000.0, 180.0);
+	clutter_actor_set_size(container_for_tracks, 2000.0, 120.0+y_offset); //track is 80 and backingtrack is 40
 
-	//Backing track (nothing visual yet)
-	gchar* filepath1 = g_strdup_printf("%s/%s/%s/backing_track.wav", THEMES_DIR, "fantasy", "140"); //TODO.
-	printf("backingtrack: '%s'\n",filepath1);
-	int fd = open(filepath1,O_RDONLY);
-	if (fd != -1) {
+	//Backing track
+	printf("backingtrack filename: '%s'\n",backing_track_filepath);
+	int fd = open(backing_track_filepath,O_RDONLY);
+	if (fd != -1) { //Found it.
 		JammoEditingTrack* backing_track = chum_create_new_empty_track(); //for backing track
-		jammo_editing_track_add_sample(backing_track, jammo_sample_new_from_file(filepath1), 0);
+		jammo_editing_track_add_sample(backing_track, jammo_sample_new_from_file(backing_track_filepath), 0);
+		g_free(backing_track_filepath);
 	}
-	g_free(filepath1);
 
 
+	ClutterActor *container_for_backingtrack_blocks = tangle_widget_new();
+	clutter_actor_set_size(container_for_backingtrack_blocks, 2000.0, 40.0);
+	clutter_actor_set_position(container_for_backingtrack_blocks, 0.0, 0.0);
+
+	int number_of_slots = create_backing_track_color_coding(background_color_code,WIDTH_OF_SLOT,y_offset,TANGLE_WIDGET(container_for_backingtrack_blocks));
+	tangle_widget_add(TANGLE_WIDGET(container_for_tracks), container_for_backingtrack_blocks, NULL);
+
 
 	//Bottom track. Below of this there will be place for scrollbar.
 	JammoEditingTrack* editing_track_theme = chum_create_new_empty_track(); //This new track is automatically putted in sequencer.
-	ClutterActor*	track_view = jammo_track_view_new(editing_track_theme, 40, 1000000000L, 40.0);
+	ClutterActor*	track_view = jammo_track_view_new(editing_track_theme, number_of_slots, 1000000000L, WIDTH_OF_SLOT);
 	clutter_actor_set_reactive(track_view, TRUE);
 	g_object_set(track_view, "line-every-nth-slot", 2, NULL);
-	clutter_actor_set_position(track_view, 0.0, 80.0);
+	clutter_actor_set_position(track_view, 0.0, 0.0+y_offset);
 	tangle_widget_add(TANGLE_WIDGET(container_for_tracks), track_view, NULL);
 
 	bottom_track_view = JAMMO_TRACK_VIEW(track_view); //This is needed when loading/saving
@@ -539,7 +609,7 @@ else { //advanced
 	if (use_two_tracks){
 	//Upper track.
 	JammoEditingTrack* editing_track_theme2 = chum_create_new_empty_track(); //This new track is automatically putted in sequencer.
-	ClutterActor*	track_view2 = jammo_track_view_new(editing_track_theme2, 40, 1000000000L, 40.0);
+	ClutterActor*	track_view2 = jammo_track_view_new(editing_track_theme2, number_of_slots, 1000000000L, WIDTH_OF_SLOT);
 	clutter_actor_set_reactive(track_view2, TRUE);
 	g_object_set(track_view2, "line-every-nth-slot", 3, NULL);
 	clutter_actor_set_position(track_view2, 0.0, 0.0);
@@ -549,8 +619,8 @@ else { //advanced
 	//Scrolling area for track (or tracks)
 	ClutterActor* scrolling_actor;
 	scrolling_actor = tangle_scrolling_actor_new(container_for_tracks);
-	clutter_actor_set_position(scrolling_actor, 0.0, 280.0);
-	clutter_actor_set_size(scrolling_actor, 800.0, 180.0);
+	clutter_actor_set_position(scrolling_actor, 0.0, 360.0-y_offset);
+	clutter_actor_set_size(scrolling_actor, 800.0, 120.0+y_offset);
 	clutter_container_add_actor(CLUTTER_CONTAINER(view), scrolling_actor);
 
 
