@@ -273,7 +273,7 @@ static void jammo_sequencer_class_init(JammoSequencerClass* klass) {
 	                                g_param_spec_boolean("ready",
 	                                "Ready",
 	                                "Whether the sequencer is ready to play or not",
-	                                FALSE,
+	                                TRUE,
 	                                G_PARAM_READABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
 	/**
 	 * JammoSequencer::stopped:
@@ -295,6 +295,9 @@ static void jammo_sequencer_init(JammoSequencer* sequencer) {
 	GstElement* sink;
 
 	sequencer->priv = G_TYPE_INSTANCE_GET_PRIVATE(sequencer, JAMMO_TYPE_SEQUENCER, JammoSequencerPrivate);
+
+	sequencer->priv->ready = TRUE;
+
 	sequencer->priv->pipeline = jammo_pipeline_new(NULL);
 	bus = gst_pipeline_get_bus(GST_PIPELINE(sequencer->priv->pipeline));
 	gst_bus_add_watch(bus, on_bus_message, sequencer);
